==> amazon-textract-idp-cdk-constructs-0.0.13.tar.gz: package/lib/textractGenerateCSV.d.ts <==
import * as iam from 'aws-cdk-lib/aws-iam';
import * as lambda_ from 'aws-cdk-lib/aws-lambda';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import * as sfn from 'aws-cdk-lib/aws-stepfunctions';
import { Construct } from 'constructs';
export declare function validatePatternSupported(integrationPattern: sfn.IntegrationPattern, supportedPatterns: sfn.IntegrationPattern[]): void;
export declare function integrationResourceArn(service: string, api: string, integrationPattern?: sfn.IntegrationPattern): string;
export interface TextractGenerateCSVProps extends sfn.TaskStateBaseProps {
    readonly csvS3OutputBucket: string;
    readonly csvS3OutputPrefix: string;
    /** memory of Lambda function (may need to increase for larger documents) */
    readonly lambdaMemoryMB?: number;
    readonly outputType?: string;
    readonly lambdaTimeout?: number;
    readonly lambdaLogLevel?: string;
    /** Which Textract API output should be converted to a CSV?
     * GENERIC and AnalyzeID and LENDING are supported.
     * @default - GENERIC */
    readonly textractAPI?: 'GENERIC' | 'ANALYZEID' | 'LENDING';
    /** The generated CSV can have any meta-data from the manifest file included.
     * This is a list of all meta-data names to include
     * If they are missed they will be ""
     * MetaData keys have to be without ','
     */
    readonly metaDataToAppend?: Array<string>;
    /**
         * The JSON input for the execution, same as that of StartExecution.
         *
         * @see https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html
         *
         * @default - The state input (JSON path '$')
         */
    readonly input?: sfn.TaskInput;
    /**
               * The name of the execution, same as that of StartExecution.
               *
               * @see https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html
               *
               * @default - None
               */
    readonly name?: string;
    /**
               * Pass the execution ID from the context object to the execution input.
               * This allows the Step Functions UI to link child executions from parent executions, making it easier to trace execution flow across state machines.
               *
               * If you set this property to `true`, the `input` property must be an object (provided by `sfn.TaskInput.fromObject`) or omitted entirely.
               *
               * @see https://docs.aws.amazon.com/step-functions/latest/dg/concepts-nested-workflows.html#nested-execution-startid
               *
               * @default - false
               */
    readonly associateWithParent?: boolean;
}
/**
 * Generates a output based on Textract Forms and Queries.
 * Supported output_types: "LINES" | "CSV"
 *
 * Input: "Payload"."textract_result"."TextractOutputJsonPath"
 * Output: "TextractOutputCSVPath" TODO: rename
 *
 *
 * Output as LINES
 * Example (Python)
 * ```python
 *         generate_text = tcdk.TextractGenerateCSV(
            self,
            "GenerateText",
            csv_s3_output_bucket=document_bucket.bucket_name,
            csv_s3_output_prefix=s3_txt_output_prefix,
            output_type='LINES',
            lambda_log_level="DEBUG",
            integration_pattern=sfn.IntegrationPattern.WAIT_FOR_TASK_TOKEN,
            input=sfn.TaskInput.from_object({
                "Token":
                sfn.JsonPath.task_token,
                "ExecutionId":
                sfn.JsonPath.string_at('$$.Execution.Id'),
                "Payload":
                sfn.JsonPath.entire_payload,
            }),
            result_path="$.txt_output_location")
   ```
 */
export declare class TextractGenerateCSV extends sfn.TaskStateBase {
    private readonly props;
    private static readonly SUPPORTED_INTEGRATION_PATTERNS;
    protected readonly taskMetrics?: sfn.TaskMetricsConfig;
    protected readonly taskPolicies?: iam.PolicyStatement[];
    private readonly integrationPattern;
    stateMachine: sfn.StateMachine;
    readonly generateCSVLogGroup: ILogGroup;
    readonly generateCSVLambda: lambda_.IFunction;
    constructor(scope: Construct, id: string, props: TextractGenerateCSVProps);
    /**
         * @internal
         */
    protected _renderTask(): any;
    /**
           * As StateMachineArn is extracted automatically from the state machine object included in the constructor,
           *
           * the scoped access policy should be generated accordingly.
           *
           * This means the action of StartExecution should be restricted on the given state machine, instead of being granted to all the resources (*).
           */
    private createScopedAccessPolicy;
}

==> amazon-textract-idp-cdk-constructs-0.0.15.tar.gz: package/lib/textractGenerateCSV.d.ts <==
import * as iam from 'aws-cdk-lib/aws-iam';
import * as lambda_ from 'aws-cdk-lib/aws-lambda';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import * as sfn from 'aws-cdk-lib/aws-stepfunctions';
import { Construct } from 'constructs';
export declare function validatePatternSupported(integrationPattern: sfn.IntegrationPattern, supportedPatterns: sfn.IntegrationPattern[]): void;
export declare function integrationResourceArn(service: string, api: string, integrationPattern?: sfn.IntegrationPattern): string;
export interface TextractGenerateCSVProps extends sfn.TaskStateBaseProps {
    readonly csvS3OutputBucket: string;
    readonly csvS3OutputPrefix: string;
    /** memory of Lambda function (may need to increase for larger documents) */
    readonly lambdaMemoryMB?: number;
    readonly outputType?: string;
    readonly lambdaTimeout?: number;
    readonly lambdaLogLevel?: string;
    /** Which Textract API output should be converted to a CSV?
     * GENERIC and AnalyzeID and LENDING are supported.
     * @default - GENERIC */
    /** List of PolicyStatements to attach to the Lambda function.  */
    readonly inputPolicyStatements?: [iam.PolicyStatement];
    /** List of PolicyStatements to attach to the Lambda function.  */
    readonly outputPolicyStatements?: [iam.PolicyStatement];
    readonly textractAPI?: 'GENERIC' | 'ANALYZEID' | 'LENDING';
    /** The generated CSV can have any meta-data from the manifest file included.
     * This is a list of all meta-data names to include
     * If they are missed they will be ""
     * MetaData keys have to be without ','
     */
    readonly metaDataToAppend?: Array<string>;
    /** Bucketname and prefix to read document from
    /** location of input S3 objects - if left empty will generate rule for s3 access to all [*] */
    readonly s3InputBucket?: string;
    /** prefix for input S3 objects - if left empty will generate rule for s3 access to all in bucket */
    readonly s3InputPrefix?: string;
    /**
         * The JSON input for the execution, same as that of StartExecution.
         *
         * @see https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html
         *
         * @default - The state input (JSON path '$')
         */
    readonly input?: sfn.TaskInput;
    /**
               * The name of the execution, same as that of StartExecution.
               *
               * @see https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html
               *
               * @default - None
               */
    readonly name?: string;
    /**
               * Pass the execution ID from the context object to the execution input.
               * This allows the Step Functions UI to link child executions from parent executions, making it easier to trace execution flow across state machines.
               *
               * If you set this property to `true`, the `input` property must be an object (provided by `sfn.TaskInput.fromObject`) or omitted entirely.
               *
               * @see https://docs.aws.amazon.com/step-functions/latest/dg/concepts-nested-workflows.html#nested-execution-startid
               *
               * @default - false
               */
    readonly associateWithParent?: boolean;
}
/**
 * Generates a output based on Textract Forms and Queries.
 * Supported output_types: "LINES" | "CSV"
 *
 * Input: "Payload"."textract_result"."TextractOutputJsonPath"
 * Output: "TextractOutputCSVPath" TODO: rename
 *
 *
 * Output as LINES
 * Example (Python)
 * ```python
 *         generate_text = tcdk.TextractGenerateCSV(
            self,
            "GenerateText",
            csv_s3_output_bucket=document_bucket.bucket_name,
            csv_s3_output_prefix=s3_txt_output_prefix,
            output_type='LINES',
            lambda_log_level="DEBUG",
            integration_pattern=sfn.IntegrationPattern.WAIT_FOR_TASK_TOKEN,
            input=sfn.TaskInput.from_object({
                "Token":
                sfn.JsonPath.task_token,
                "ExecutionId":
                sfn.JsonPath.string_at('$$.Execution.Id'),
                "Payload":
                sfn.JsonPath.entire_payload,
            }),
            result_path="$.txt_output_location")
   ```
 */
export declare class TextractGenerateCSV extends sfn.TaskStateBase {
    private readonly props;
    private static readonly SUPPORTED_INTEGRATION_PATTERNS;
    protected readonly taskMetrics?: sfn.TaskMetricsConfig;
    protected readonly taskPolicies?: iam.PolicyStatement[];
    private readonly integrationPattern;
    stateMachine: sfn.StateMachine;
    readonly generateCSVLogGroup: ILogGroup;
    readonly generateCSVLambda: lambda_.IFunction;
    constructor(scope: Construct, id: string, props: TextractGenerateCSVProps);
    /**
         * @internal
         */
    protected _renderTask(): any;
    /**
           * As StateMachineArn is extracted automatically from the state machine object included in the constructor,
           *
           * the scoped access policy should be generated accordingly.
           *
           * This means the action of StartExecution should be restricted on the given state machine, instead of being granted to all the resources (*).
           */
    private createScopedAccessPolicy;
}
